@@ -4,11 +4,11 @@ import mock
 from cpm.api.build import build_project
 from cpm.domain.project.project_loader import InvalidTarget
 from cpm.domain.project_commands import DockerImageNotFound, BuildError
-from cpm.domain.project.project_descriptor_parser import ProjectDescriptorNotFound
+from cpm.domain.project.project_descriptor_parser import ProjectDescriptorNotFound, ParseError
 
 
 class TestApiBuild(unittest.TestCase):
-    def test_build_fails_when_current_directory_is_not_a_chromos_project(self):
+    def test_build_fails_when_current_directory_is_not_a_cpm_project(self):
         recipe = mock.MagicMock()
         compilation_service = mock.MagicMock()
         compilation_service.build.side_effect = ProjectDescriptorNotFound()
@@ -18,6 +18,16 @@ class TestApiBuild(unittest.TestCase):
         assert result.status_code == 1
         compilation_service.build.assert_called_once_with(recipe)
 
+    def test_build_fails_when_descriptor_contains_errors(self):
+        recipe = mock.MagicMock()
+        compilation_service = mock.MagicMock()
+        compilation_service.build.side_effect = ParseError('project.yaml', 1, 1, 'error')
+
+        result = build_project(compilation_service, recipe)
+
+        assert result.status_code == 1
+        compilation_service.build.assert_called_once_with(recipe)
+
     def test_build_fails_when_compilation_fails(self):
         recipe = mock.MagicMock()
         compilation_service = mock.MagicMock()
@@ -59,7 +69,6 @@ class TestApiBuild(unittest.TestCase):
 
     def test_build_project_for_target(self):
         compilation_service = mock.MagicMock()
-        recipe = mock.MagicMock()
 
         result = build_project(compilation_service, target='raspberrypi4:64')
 
